@@ -7,9 +7,9 @@ pub fn object(key: &str, val: &str) -> Vec<u8> {
 
     let vb: Vec<u8> = val.to_string().into_bytes();
 
-    let vl: u8 = vb.len() as u8;
+    let vl: u64 = vb.len() as u64;
 
-    [vec![kl, vl], kb, vb].concat()
+    [vec![kl], vl.to_le_bytes().to_vec(), kb, vb].concat()
 
 }
 
