@@ -10,7 +10,8 @@ pub fn bytes(val: &Vec<u8>) -> String {
 }
 
 fn encode_hex(bytes: &Vec<u8>) -> String {
-    let mut s = String::with_capacity(bytes.len() * 2);
+    let mut s = String::with_capacity((bytes.len() * 2) + 2);
+    s.push_str("0X");
     for &b in bytes {
         write!(&mut s, "{:02X}", b).unwrap();
     }
